class ConstrainedSketchConstraint:
    """The ConstrainedSketchConstraint object stores the constraints associated with a sketch.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import sketch
            mdb.models[name].sketches[name].constraints[i]
    """

    pass
