from .DirectDampingByFrequencyComponent import DirectDampingByFrequencyComponent


class DirectDampingByFrequencyComponentArray(list[DirectDampingByFrequencyComponent]):
    def findAt(self):
        pass
